package hu.bme.mit.books.manager;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

import hu.bme.mit.books.model.Book;


import org.eclipse.core.databinding.observable.list.WritableList;

public class BookManager implements IBookManager{

	List<Book> books;
	WritableList bookListObservable;

	/**
	 * Instantiates a new book manager with three sample books.
	 */
	public BookManager() {
		books = new ArrayList<Book>();
	}

	/**
	 * Gets the all books.
	 * 
	 * @return the all books
	 */
	@Override
	public WritableList observeAllBooks() {
		if (bookListObservable == null)
			bookListObservable = new WritableList(books, Book.class);
		return bookListObservable;
	}

	public List<Book> getAllBooks() {
		return books;
	}

	/**
	 * Adds a book with a given author, title, page number to the manager, and
	 * sets whether it is read or not.
	 * 
	 * @param author
	 *            the author
	 * @param title
	 *            the title
	 * @param pages
	 *            the pages
	 * @param read
	 *            the read
	 */
	@Override
	public void addBook(String author, String title, int pages, boolean read) {
		Book book = new Book();
		book.setAuthor(author);
		book.setTitle(title);
		book.setPagenum(pages);
		book.setRead(read);
		addBook(book);
	}
	
	@Override
	public void addBook(Book book) {
		if (bookListObservable != null) {
			bookListObservable.add(book);
		} else {
			books.add(book);
		}
	}
	
	@Override
	public void removeBook(Book book) {
		if (bookListObservable != null) {
			bookListObservable.remove(book);
		} else {
			books.remove(book);
		}
	}
	
	@Override
	public List<Book> getBookOfAuthor(String name)
			throws IllegalArgumentException {
		if (name == null || name.isEmpty())
			throw new IllegalArgumentException(
					"Parameter should be an author name.");
		ArrayList<Book> books = new ArrayList<Book>();
		for (Book book : this.books) {
			if (name.equals(book.getAuthor())) {
				books.add(book);
				//return books;
			}
		}
		return books;
	}
}
